@@ -4,6 +4,9 @@ binom.pval <- function (k, n, p=.5, alternative=c("two.sided", "less", "greater"
   if (any(k < 0) || any(k > n) || any(n < 1)) stop("arguments must be integer vectors with 0 <= k <= n")
   if (any(p < 0) || any(p > 1)) stop("null hypothesis proportion p must be in range [0,1]")
   
+  ## ensure that all frequency data are floating-point (double), in particular guarding against bit64::integer64 vectors
+  .ensure.double(c("k", "n"))
+  
   pval <- switch(alternative,
                  two.sided = 2 * pmin(pbinom(k, n, p, lower.tail=TRUE), pbinom(k-1, n, p, lower.tail=FALSE)),
                  less      = pbinom(k, n, p, lower.tail=TRUE),
